import { cloneDeep } from "lodash";
import { AnyFun } from "queenjs/typing";
import { EditorModule } from "../..";
import { Action, HistoryController } from "./HistoryController";

export class HistoryCtrl {
  history: HistoryController;
  historyActionDoing = false;

  constructor(protected module: EditorModule, historyTotal = 50) {
    this.history = new HistoryController(historyTotal);
  }

  onChange(root: any, type: string, paths: string[], value: any) {
    const action = new Action(
      root,
      `${type}:${paths.join(".")}`,
      cloneDeep(value)
    );
    this.history.record(action);
  }

  proxyActions(actNames: string[]) {
    const actions: any = this.module.actions;
    actNames.forEach((actName) => {
      const action = actions[actName];
      actions[actName] = this.proxyAction.bind(this, action);
    });
  }

  async proxyAction(action: AnyFun, ...args: any[]) {
    if (this.historyActionDoing) {
      return await action(...args);
    }
    const { history } = this;
    try {
      this.historyActionDoing = true;
      history.group = true;
      await action(...args);
      history.group = false;
    } catch (error) {
      if (history.groupQueue.length) {
        history.group = false;
        history.undo();
        history.queue.pop();
        history.state.lenth--;
      } else {
        history.group = false;
      }
    } finally {
      this.historyActionDoing = false;
    }
  }
}
