import { BusController } from "@/controllers/natsController";
import { TreeController } from "@/controllers/queentreeController";
import "@/modules/_default/viewerStorage";
import {
  initQueentreeExplorer,
  NodeTypes,
} from "@queenjs-modules/queentree-explorer";
import PickNodeSteps from "@queenjs-modules/queentree-explorer/components/PickNodeSteps";
import PickNodeStep from "@queenjs-modules/queentree-explorer/components/PickNodeSteps/PickNodeStep";
import { StepController } from "@queenjs-modules/queentree-explorer/components/PickNodeSteps/StepController";
import { Exception, useModal } from "queenjs";
import { defineComponent } from "vue";
import { array } from "vue-types";

export default defineComponent({
  props: {
    nodeTypes: array<NodeTypes>().def(["packProd"]),
  },

  setup(props) {
    document.title = "选择材质球";

    const stepCtrol = new StepController(1);
    // const modal = useModal();
    const _bus = new BusController();
    _bus.init(_bus.getQuery("bus"));
    const _tree = new TreeController(_bus);

    initQueentreeExplorer({
      config: {
        showNodeToolbar: false,
        nodeListColumns: 6,
      },
    });

    async function submit() {
     try {
        const branchFolder = stepCtrol.state.data.pickNodes[0];
        const pack = await branchFolder.getAssetDetail();

        let mat;
        switch (branchFolder.nodeType) {
          case "matGroupItem":
            mat = pack.source.colorCards.find(
              (d: any) => d.id == branchFolder.state.id
            );
            break;
          case "packMat":
            mat = pack.source.mats.find(
              (d: any) => d.id == branchFolder.state.id
            );
            break;
          case "mat":
            mat = pack.source
            break;
        }
        _tree.CloseTreeOpen("selmatblack", mat)
        return;
      } catch (error: any) {
        Exception.error(error?.toString());
      }
      _tree.CloseTreeOpen("selmatblack")
    }
    
    return () => {
      const { nodeTypes } = props;
      return (
        <PickNodeSteps
          onSubmit={submit}
          onCancel={() =>{
            console.log("cancel")
            _tree.CloseTreeOpen("selmatblack");
          }}
          control={stepCtrol}
          lastStepText="确定"
          steps={[
            {
              title: "选择",
              content: () => (
                <PickNodeStep
                  control={stepCtrol}
                  options={{
                    nodeTypes: nodeTypes,
                    //   childNodeType: "packProd",
                  }}
                />
              ),
            },
          ]}
        />
      );
    };
  },
});
