import { css, cx } from "@linaria/core";
import { Image, View } from "@queenjs/ui";
import { Checkbox, Radio, RadioChangeEvent } from "ant-design-vue";
import { defineUI } from "queenjs";
import { reactive } from "vue";
import { any, bool } from "vue-types";

const options = [
  { label: "1倍", value: 1 },
  { label: "2倍", value: 2 },
];

export default defineUI({
  props: {
    active: bool(),
    record: any(),
  },
  emits: ["select", "change"],
  setup(props, { emit }) {
    const state = reactive({
      qos: 1,
    });

    const change = (e: RadioChangeEvent) => {
      state.qos = e.target.value;
      emit("change", state.qos);
    };

    return () => {
      const { active, record } = props;
      //   console.log("record: ", record);
      return (
        <div>
          <View
            ratio={1.4}
            onClick={() => emit("select")}
            class={cx(
              itemStyles,
              "overflow-hidden",
              "relative",
              active && "active"
            )}
          >
            {active && (
              <Checkbox
                checked
                class="!-mt-0.2em absolute top-0 left-0 text-20px text-red-200 z-3"
              />
            )}
            <Image class="h-1/1 w-1/1" src={record?.thumbnailUrl} />
          </View>
          <div>
            <div class="py-8px">
              尺寸：{record.width} * {record.height}
            </div>
            <div>
              渲染分辨率：
              <Radio.Group
                disabled={!props.active}
                value={state.qos}
                options={options}
                onChange={change}
              />
            </div>
          </div>
        </div>
      );
    };
  },
});

const itemStyles = css`
  border: 1px solid transparent;
  &.active {
    border-color: @inf-primary-color;
  }
`;
