import { Button } from "ant-design-vue";
import { defineComponent } from "vue";
import { css, cx } from "@linaria/core";
import { any } from "vue-types";
import { BtnNames, MaterialController, TabNames } from "../../../../modules/resource/controllers/MaterialController";
import { defineUI } from "queenjs";

const materialType = [
  { name: "视频", key: "video" },
  { name: "图片", key: "image" },
  { name: "渲染任务", key: "task" },
];

export default defineUI({
  
  props: {
    Controller: any<MaterialController>().isRequired,
  },
  setup(props, { emit }) {
    return () => {
      const state = props.Controller.state;

      return (
            <div class="flex items-center justify-between mt-20px">
            <div class="filter space-x-60px">
              {state.tabs.map((d) => (
                <span
                  key={d}
                  onClick={() => props.Controller.switchTab(d)}
                  class={cx(
                        state.currTab == d && "active",
                       "cursor-pointer btn_tab"
                    )}
                >
                  {TabNames[d as "video"]}
                </span>
              ))}
            </div>
            <div>
              {
                state.btns.map((name, index)=>
                    <Button
                        ghost
                        key={name}
                        type="primary"
                        class={"primary" + (index > 0 ? " ml-25px" : "")}
                        onClick={()=>props.Controller.onBtnClick(name)}
                  >
                     {BtnNames[name as "video"]}
                  </Button>
                )
              }
            </div>
          </div>
      );
    };
  },
});

const rootStyles = css`
  .btn_tab {
    padding: 3px 5px;
    &:hover,
    &.active {
      color: @inf-primary-color;
    }
  }
`;
